#include "tsl2591_lux.h"

/**************************************************************************/
/*
    Configures the gain and integration time for the TSL2591
*/
/**************************************************************************/

Adafruit_TSL2591 tsl_l = Adafruit_TSL2591(2591);

void tsl2591_lux::configureSensor(void)
{
  // You can change the gain on the fly, to adapt to brighter/dimmer light situations
  tsl_l.setGain(TSL2591_GAIN_LOW);    // 1x gain (bright light)
  //tsl.setGain(TSL2591_GAIN_MED);      // 25x gain
  // tsl.setGain(TSL2591_GAIN_HIGH);   // 428x gain

  // Changing the integration time gives you a longer time over which to sense light
  // longer timelines are slower, but are good in very low light situtations!
  tsl_l.setTiming(TSL2591_INTEGRATIONTIME_100MS);  // shortest integration time (bright light)
  // tsl.setTiming(TSL2591_INTEGRATIONTIME_200MS);
  // tsl.setTiming(TSL2591_INTEGRATIONTIME_300MS);
  // tsl.setTiming(TSL2591_INTEGRATIONTIME_400MS);
  // tsl.setTiming(TSL2591_INTEGRATIONTIME_500MS);
  // tsl.setTiming(TSL2591_INTEGRATIONTIME_600MS);  // longest integration time (dim light)

  /* Display the gain and integration time for reference sake */
  tsl2591Gain_t gain = tsl_l.getGain();

  /* Setup the SW interrupt to trigger between 100 and 1500 lux */
  /* Threshold values are defined at the top of this sketch */
  tsl_l.clearInterrupt();
  tsl_l.registerInterrupt(TLS2591_INT_THRESHOLD_LOWER,
                        TLS2591_INT_THRESHOLD_UPPER,
                        TLS2591_INT_PERSIST);
}

uint32_t tsl2591_lux::ReadLux(void)
{
  // More advanced data read example. Read 32 bits with top 16 bits IR, bottom 16 bits full spectrum
  // That way you can do whatever math and comparisons you want!
  uint32_t lum = tsl_l.getFullLuminosity();
  tsl_l.clearInterrupt();
  return lum;
}

uint8_t tsl2591_lux::getStatus(void)
{
  uint8_t x = tsl_l.getStatus();
  return x;
  // bit 4: ALS Interrupt occured
  // bit 5: No-persist Interrupt occurence
}

float tsl2591_lux::calculatelux(void)
{
  //uint8_t x = tsl_l.getStatus();
  uint32_t lum = tsl_l.getFullLuminosity();
  uint16_t ir, full;
  ir = lum >> 16;
  full = lum & 0xFFFF;
  return tsl_l.calculateLux(full, ir);
}